@@ -17,17 +17,20 @@ class SortQL(QuerySetReader, BaseRecursiveDriver):
         Example::
         - !ReduceAllDriver
             with:
-                traverse_on: matches
+                granularity_range: [0, 0]
+                adjacency_range: [0, 1]
         - !SortQL
             with:
                 reverse: true
                 field: 'score.value'
-                traverse_on: matches
+                granularity_range: [0, 0]
+                adjacency_range: [0, 1]
         - !SliceQL
             with:
                 start: 0
                 end: 50
-                traverse_on: matches
+                granularity_range: [0, 0]
+                adjacency_range: [0, 1]
 
         `SortQL` will ensure that only the documents are sorted by the score value before slicing the first top 50 documents
     """
@@ -43,6 +46,6 @@ class SortQL(QuerySetReader, BaseRecursiveDriver):
         self._field = field
         self.is_apply = False
 
-    def _apply_all(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs):
+    def _apply_all(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs) -> None:
         docs.sort(key=lambda x: rgetattr(x, self.field), reverse=self.reverse)
 
