@@ -20,7 +20,7 @@ class BigTransferEncoder(BaseTFEncoder):
         Known issue: this does not work on tensorflow==2.2.0, https://github.com/tensorflow/tensorflow/issues/38571
     """
 
-    def __init__(self, model_path: str, channel_axis: int = 1, *args, **kwargs):
+    def __init__(self, model_path: str = None, channel_axis: int = 1, *args, **kwargs):
         """
         :param model_path: the path of the model in the `SavedModel` format. `model_path` should be a directory path,
             which has the following structure. The pretrained model can be downloaded at
@@ -50,6 +50,7 @@ class BigTransferEncoder(BaseTFEncoder):
         super().post_init()
         self.to_device()
         import tensorflow as tf
+        self.logger.info(f'model_path: {self.model_path}')
         _model = tf.saved_model.load(self.model_path)
         self.model = _model.signatures['serving_default']
         self._get_input = tf.convert_to_tensor
