@@ -1,6 +1,7 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
+from dataclasses import dataclass
 import os
 from typing import Optional
 
@@ -29,18 +30,21 @@ def auto_reduce(model_outputs: 'np.ndarray', mask_2d: 'np.ndarray', model_name:
     return reduce_cls(model_outputs, mask_2d, cls_pos='tail')
 
 
-class TransformerTFEncoder(TFDevice, BaseEncoder):
+@dataclass
+class Transformer:
+    pretrained_model_name_or_path: str = 'bert-base-uncased'
+    pooling_strategy: str = 'auto'
+    max_length: Optional[int] = None
+    truncation_strategy: str = 'longest_first'
+    model_save_path: Optional[str] = None
+
+
+class TransformerTFEncoder(TFDevice, BaseEncoder, Transformer):
     """
     Internally, TransformerTFEncoder wraps the tensorflow-version of transformers from huggingface.
     """
 
-    def __init__(self,
-                 pretrained_model_name_or_path: str = 'bert-base-uncased',
-                 pooling_strategy: str = 'auto',
-                 max_length: Optional[int] = None,
-                 truncation_strategy: str = 'longest_first',
-                 model_save_path: Optional[str] = None,
-                 *args, **kwargs):
+    def __init__(self, *args, **kwargs):
         """
         :param pretrained_model_name_or_path: Either:
             - a string with the `shortcut name` of a pre-trained model to load from cache or download, e.g.: ``bert-base-uncased``.
@@ -63,11 +67,6 @@ class TransformerTFEncoder(TFDevice, BaseEncoder):
             `model_save_path` should be relative to executor's workspace
         """
         super().__init__(*args, **kwargs)
-        self.pretrained_model_name_or_path = pretrained_model_name_or_path
-        self.pooling_strategy = pooling_strategy
-        self.max_length = max_length
-        self.model_save_path = model_save_path
-        self.truncation_strategy = truncation_strategy
 
     def __getstate__(self):
         if self.model_save_path:
@@ -94,6 +93,7 @@ class TransformerTFEncoder(TFDevice, BaseEncoder):
     def model(self):
         from transformers import TFAutoModelForPreTraining
         model = TFAutoModelForPreTraining.from_pretrained(self.pretrained_model_name_or_path)
+        self.to_device()
         return model
 
     @cached_property
@@ -103,7 +103,6 @@ class TransformerTFEncoder(TFDevice, BaseEncoder):
 
     @cached_property
     def tensor_func(self):
-        self.to_device()
         import tensorflow as tf
         return tf.constant
 
@@ -142,7 +141,7 @@ class TransformerTFEncoder(TFDevice, BaseEncoder):
                                  output_hidden_states=True)
 
             hidden_states = outputs[-1]
-            output_embeddings = hidden_states[0]
+            output_embeddings = hidden_states[-1]
             _mask_ids_batch = self.tensor2array(mask_ids_batch)
             _seq_output = self.tensor2array(output_embeddings)
             if self.pooling_strategy == 'auto':
