@@ -7,7 +7,11 @@ import numpy as np
 from jina.executors.indexers.vector import BaseNumpyIndexer
 from jina.executors.decorators import batching
 
+
 class NmsLibIndexer(BaseNumpyIndexer):
+
+    batch_size = 512
+
     """nmslib powered vector indexer
 
     For documentation and explanation of each parameter, please refer to
@@ -45,13 +49,11 @@ class NmsLibIndexer(BaseNumpyIndexer):
         _index.createIndex({'post': 2}, print_progress=self.print_progress)
         return _index
 
-    @batching(batch_size=512)
+    @batching
     def build_partial_index(self, vecs: 'np.ndarray', _index):
         _index.addDataPointBatch(vecs.astype(np.float32))
 
     def query(self, keys: 'np.ndarray', top_k: int, *args, **kwargs) -> Tuple['np.ndarray', 'np.ndarray']:
-        # if keys.dtype != np.float32:
-        #     raise ValueError('vectors should be ndarray of float32')
         ret = self.query_handler.knnQueryBatch(keys, k=top_k, num_threads=self.num_threads)
         idx, dist = zip(*ret)
         return self.int2ext_id[np.array(idx)], np.array(dist)
