@@ -53,14 +53,17 @@ def set_logger_parser(parser=None):
 
 
 def set_hub_base_parser(parser=None):
+    import os
     if not parser:
         parser = set_base_parser()
-    parser.add_argument('--username', type=str, help='the registry username')
+    parser.add_argument('--username', type=str, help='the registry username',
+                        default=os.environ.get('JINAHUB_USERNAME', ''))
     # _gp = parser.add_mutually_exclusive_group()
     # _gp.add_argument('--password-stdin', type=argparse.FileType('r'),
     #                  default=(sys.stdin if sys.stdin.isatty() else None),
     #                  help='take the password from stdin')
-    parser.add_argument('--password', type=str, help='the plaintext password')
+    parser.add_argument('--password', type=str, help='the plaintext password',
+                        default=os.environ.get('JINAHUB_PASSWORD', ''))
     parser.add_argument('--registry', type=str, default='https://index.docker.io/v1/',
                         help='the URL to the registry, e.g. https://index.docker.io/v1/')
 
@@ -74,7 +77,9 @@ def set_hub_new_parser(parser=None):
     parser.add_argument('--output-dir', type=str, default='.',
                         help='where to output the generated project dir into.')
     parser.add_argument('--template', type=str, default='https://github.com/jina-ai/cookiecutter-jina-hub.git',
-                        help='s directory containing a project template directory, or a URL to a git repository.')
+                        help='cookiecutter template directory containing a project template directory, or a URL to a git repository. Only used when "--type template"')
+    parser.add_argument('--type', type=str, default='pod', choices=['pod', 'app', 'template'],
+                        help='create a template for executor hub pod or app using cookiecutter.')
     parser.add_argument('--overwrite', action='store_true', default=False,
                         help='overwrite the contents of output directory if it exists')
     return parser
@@ -101,6 +106,12 @@ def set_hub_build_parser(parser=None):
                         help='prune unused images after building, this often saves disk space')
     parser.add_argument('--raise-error', action='store_true', default=False,
                         help='raise any error and exit with code 1')
+    parser.add_argument('--test-uses', action='store_true', default=False,
+                        help='after the build, test the image in "uses" with Flow API')
+    parser.add_argument('--host-info', action='store_true', default=False,
+                        help='store the host information during bookkeeping')
+    parser.add_argument('--daemon', action='store_true', default=False,
+                        help='run the test Pea/Pod as a daemon process, see "jina pea --help" for details')
     return parser
 
 
@@ -173,7 +184,7 @@ def set_flow_parser(parser=None):
     from ..enums import FlowOutputType, FlowOptimizeLevel
 
     gp = add_arg_group(parser, 'flow arguments')
-    gp.add_argument('--yaml-path', type=str, help='a yaml file represents a flow')
+    gp.add_argument('--uses', type=str, help='a yaml file represents a flow')
     from pkg_resources import resource_filename
     gp.add_argument('--logserver', action='store_true', default=False,
                     help='start a log server for the dashboard')
@@ -304,6 +315,9 @@ def set_pea_parser(parser=None):
     gp6.add_argument('--max-idle-time', type=int, default=60,
                      help='label this pea as inactive when it does not '
                           'process any request after certain time (in second)')
+    gp6.add_argument('--daemon', action='store_true', default=False,
+                     help='when a process exits, it attempts to terminate all of its daemonic child processes. '
+                          'setting it to true basically tell the context manager do not wait on this Pea')
 
     gp7 = add_arg_group(parser, 'logging arguments')
     gp7.add_argument('--log-sse', action='store_true', default=False,
@@ -338,8 +352,11 @@ def set_pod_parser(parser=None):
     gp4.add_argument('--scheduling', type=SchedulerType.from_string, choices=list(SchedulerType),
                      default=SchedulerType.LOAD_BALANCE,
                      help='the strategy of scheduling workload among peas')
-    gp4.add_argument('--uses-reducing', type=str, default='_merge',
-                     help='the executor used for reducing the result from all parallel, '
+    gp4.add_argument('--uses-before', type=str,
+                     help='the executor used before sending to all parallels, '
+                          'accepted type follows "--uses"')
+    gp4.add_argument('--uses-after', type=str,
+                     help='the executor used after receiving from all parallels, '
                           'accepted type follows "--uses"')
     gp4.add_argument('--shutdown-idle', action='store_true', default=False,
                      help='shutdown this pod when all peas are idle')
@@ -553,8 +570,8 @@ def get_main_parser():
                                         'to get detailed information about each sub-command', required=True)
 
     set_hub_new_parser(
-        spp.add_parser('new', help='create a new Hub executor using cookiecutter',
-                       description='Create a new Hub executor using cookiecutter',
+        spp.add_parser('new', aliases=['init', 'create'], help='create a new Hub executor or app using cookiecutter',
+                       description='Create a new Hub executor or app using cookiecutter',
                        formatter_class=_chf))
 
     set_hub_build_parser(
