@@ -4,6 +4,7 @@ __license__ = "Apache-2.0"
 import argparse
 import copy
 import time
+from argparse import Namespace
 from contextlib import ExitStack
 from queue import Empty
 from threading import Thread
@@ -15,12 +16,12 @@ from .head_pea import HeadPea
 from .tail_pea import TailPea
 from .. import __default_host__
 from ..enums import *
-from ..helper import random_port, get_random_identity, get_parsed_args, get_non_defaults_args, valid_local_config_source
+from ..helper import random_port, get_random_identity, get_parsed_args, get_non_defaults_args, \
+    is_valid_local_config_source
 from ..main.parser import set_pod_parser, set_gateway_parser
-from argparse import Namespace
 
 
-class BasePod:
+class BasePod(ExitStack):
     """A BasePod is a immutable set of peas, which run in parallel. They share the same input and output socket.
     Internally, the peas can run with the process/thread backend. They can be also run in their own containers
     """
@@ -30,6 +31,7 @@ class BasePod:
 
         :param args: arguments parsed from the CLI
         """
+        super().__init__()
         self.peas = []
         self.is_head_router = False
         self.is_tail_router = False
@@ -37,7 +39,7 @@ class BasePod:
         self.deducted_tail = None
         if hasattr(args, 'polling') and args.polling.is_push:
             # ONLY reset when it is push
-            args.uses_reducing = '_pass'
+            args.uses_after = '_pass'
 
         if getattr(args, 'parallel', 1) > 1:
             self.is_head_router = True
@@ -57,7 +59,6 @@ class BasePod:
         while True:
             if self.is_idle:
                 self.close()
-                break  # only run once
             time.sleep(1)
 
     @property
@@ -185,17 +186,16 @@ class BasePod:
         Note that this method has a timeout of ``timeout_ready`` set in CLI,
         which is inherited from :class:`jina.peapods.peas.BasePea`
         """
-        self.stack = ExitStack()
         # start head and tail
         if self.peas_args['head']:
             p = HeadPea(self.peas_args['head'])
             self.peas.append(p)
-            self.stack.enter_context(p)
+            self.enter_context(p)
 
         if self.peas_args['tail']:
             p = TailPea(self.peas_args['tail'])
             self.peas.append(p)
-            self.stack.enter_context(p)
+            self.enter_context(p)
 
         # start real peas and accumulate the storage id
         if len(self.peas_args['peas']) > 1:
@@ -209,7 +209,7 @@ class BasePod:
             _args.role = role
             p = Pea(_args, allow_remote=False)
             self.peas.append(p)
-            self.stack.enter_context(p)
+            self.enter_context(p)
 
         self.start_sentinels()
         return self
@@ -256,7 +256,7 @@ class BasePod:
         return True
 
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
-        self.close()
+        super().__exit__(exc_type, exc_val, exc_tb)
 
     def join(self):
         """Wait until all peas exit"""
@@ -268,9 +268,6 @@ class BasePod:
         finally:
             self.peas.clear()
 
-    def close(self) -> None:
-        self.stack.close()
-
 
 class MutablePod(BasePod):
     """A :class:`MutablePod` is a pod where all peas and their connections are given"""
@@ -374,8 +371,7 @@ class FlowPod(BasePod):
         else:
             from .remote import RemoteMutablePod
             _remote_pod = RemoteMutablePod(self.peas_args)
-            self.stack = ExitStack()
-            self.stack.enter_context(_remote_pod)
+            self.enter_context(_remote_pod)
             self.start_sentinels()
             return self
 
@@ -416,16 +412,16 @@ def _copy_to_head_args(args: Namespace, is_push: bool, as_router: bool = True) -
         if args.scheduling == SchedulerType.ROUND_ROBIN:
             _head_args.socket_out = SocketType.PUSH_BIND
             if as_router:
-                _head_args.uses = '_pass'
+                _head_args.uses = args.uses_before or '_pass'
         elif args.scheduling == SchedulerType.LOAD_BALANCE:
             _head_args.socket_out = SocketType.ROUTER_BIND
             if as_router:
-                _head_args.uses = '_route'
+                _head_args.uses = args.uses_before or '_route'
     else:
         _head_args.socket_out = SocketType.PUB_BIND
         _head_args.num_part = args.parallel
         if as_router:
-            _head_args.uses = '_pass'
+            _head_args.uses = args.uses_before or '_pass'
 
     if as_router:
         _head_args.name = args.name or ''
@@ -443,7 +439,7 @@ def _copy_to_tail_args(args: Namespace, as_router: bool = True) -> Namespace:
     _tail_args.socket_in = SocketType.PULL_BIND
     _tail_args.uses = None
     if as_router:
-        _tail_args.uses = args.uses_reducing
+        _tail_args.uses = args.uses_after or '_merge'
         _tail_args.name = args.name or ''
         _tail_args.role = PeaRoleType.TAIL
 
@@ -455,7 +451,8 @@ def _fill_in_host(bind_args: Namespace, connect_args: Namespace) -> str:
 
     bind_local = (bind_args.host == '0.0.0.0')
     conn_local = (connect_args.host == '0.0.0.0')
-    conn_docker = (getattr(connect_args, 'uses', None) is not None and not valid_local_config_source(connect_args.uses))
+    conn_docker = (
+                getattr(connect_args, 'uses', None) is not None and not is_valid_local_config_source(connect_args.uses))
     bind_conn_same_remote = not bind_local and not conn_local and (bind_args.host == connect_args.host)
     if platform == "linux" or platform == "linux2":
         local_host = '0.0.0.0'
@@ -479,11 +476,10 @@ class GatewayPod(BasePod):
     """A :class:`BasePod` that holds a Gateway """
 
     def start(self) -> 'GatewayPod':
-        self.stack = ExitStack()
         for s in self.all_args:
             p = RESTGatewayPea(s) if getattr(s, 'rest_api', False) else GatewayPea(s)
             self.peas.append(p)
-            self.stack.enter_context(p)
+            self.enter_context(p)
 
         self.start_sentinels()
         return self
